==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebSortingExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSortingStrategyDescriptionMetadata } from "./WebSortingStrategyDescriptionMetadata";
import { WebBaseEventArgsDescriptionMetadata } from "./WebBaseEventArgsDescriptionMetadata";
import { WebSortingExpressionDescription } from "./WebSortingExpressionDescription";
/**
 * @hidden
 */
export let WebSortingExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebSortingExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (WebSortingExpressionDescriptionMetadata.a == null) {
                WebSortingExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebSortingExpressionDescriptionMetadata.c(WebSortingExpressionDescriptionMetadata.a);
            }
            if (a.j(WebSortingExpressionDescriptionMetadata.a)) {
                return;
            }
            a.y(WebSortingExpressionDescriptionMetadata.a);
            WebSortingStrategyDescriptionMetadata.d(a);
        }
        static c(a) {
            WebBaseEventArgsDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:SortingExpression");
            a.item("__packageNameWC", "String:grids");
            a.item("__isPlainObject", "Boolean");
            a.item("FieldName", "String");
            a.item("Dir", "ExportedType:string:SortingDirection");
            a.item("Dir@names", "None;Asc;Desc");
            a.item("Dir@constantValues", "0;1;2");
            a.item("IgnoreCase", "Boolean");
            a.item("Strategy", "ExportedType:WebSortingStrategy");
        }
        static d(a) {
            WebSortingExpressionDescriptionMetadata.b(a);
            a.aa("WebSortingExpression", () => new WebSortingExpressionDescription());
            a.z("WebSortingExpression", WebSortingExpressionDescriptionMetadata.a);
        }
    }
    WebSortingExpressionDescriptionMetadata.$t = /*@__PURE__*/ markType(WebSortingExpressionDescriptionMetadata, 'WebSortingExpressionDescriptionMetadata');
    WebSortingExpressionDescriptionMetadata.a = null;
    return WebSortingExpressionDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebSortingExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSortingStrategyDescriptionMetadata } from "./WebSortingStrategyDescriptionMetadata";
import { WebBaseEventArgsDescriptionMetadata } from "./WebBaseEventArgsDescriptionMetadata";
import { WebSortingExpressionDescription } from "./WebSortingExpressionDescription";
/**
 * @hidden
 */
export let WebSortingExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebSortingExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (WebSortingExpressionDescriptionMetadata.a == null) {
                WebSortingExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebSortingExpressionDescriptionMetadata.c(WebSortingExpressionDescriptionMetadata.a);
            }
            if (a.k(WebSortingExpressionDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebSortingExpressionDescriptionMetadata.a);
            WebSortingStrategyDescriptionMetadata.d(a);
        }
        static c(a) {
            WebBaseEventArgsDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:SortingExpression");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("FieldName", "String");
            a.item("Dir", "ExportedType:string:SortingDirection");
            a.item("Dir@names", "None;Asc;Desc");
            a.item("Dir@constantValues", "0;1;2");
            a.item("IgnoreCase", "Boolean");
            a.item("Strategy", "ExportedType:WebSortingStrategy");
        }
        static d(a) {
            WebSortingExpressionDescriptionMetadata.b(a);
            a.ac("WebSortingExpression", () => new WebSortingExpressionDescription());
            a.ab("WebSortingExpression", WebSortingExpressionDescriptionMetadata.a);
        }
    }
    WebSortingExpressionDescriptionMetadata.$t = /*@__PURE__*/ markType(WebSortingExpressionDescriptionMetadata, 'WebSortingExpressionDescriptionMetadata');
    WebSortingExpressionDescriptionMetadata.a = null;
    return WebSortingExpressionDescriptionMetadata;
})();
